Index — Fleras

Skip to main content
`Ctrl`+`K`

# Index

_ | F | M | P | U

## _

__setattr__() (fleras.EasyDict method) | __setitem__ (fleras.EasyDict attribute)

## F

fleras module fleras.EasyDict (built-in class) | fleras.fused_renorm module fleras.fused_renorm.BatchNormalization (built-in class) fleras.TrainingJob (built-in class)

## M

module fleras fleras.fused_renorm

## P

pop() (fleras.EasyDict method)

## U

update() (fleras.EasyDict method)